
Authors
=======

* `Federico Tartarini`_
* `Stefano Schiavon`_
* `Tyler Hoyt`_
* Chris Mackey

.. _Federico Tartarini: https://www.linkedin.com/in/federico-tartarini-3991995b/
.. _Stefano Schiavon: https://www.linkedin.com/in/stefanoschiavon/
.. _Tyler Hoyt: https://www.linkedin.com/in/tyler-hoyt1/

**Derivative work**

`pythermalcomfort`_ is a derivative work of the following software projects:

* `CBE Comfort Tool`_ for indoor thermal comfort calculations. Available under GPL.
* `ladybug-comfort`_. Available under GPL.
* `UTCI`_ Fortran Code for outdoor thermal comfort calculations. Available under MIT.

.. _pythermalcomfort: https://pypi.org/project/pythermalcomfort/
.. _CBE Comfort Tool: https://comfort.cbe.berkeley.edu
.. _ladybug-comfort: https://pypi.org/project/ladybug-comfort/
.. _UTCI: http://www.utci.org/index.php
